@@ -91,6 +91,18 @@ static CU_SuiteInfo suites[] = {
 		.pCleanupFunc = suite_vcn_tests_clean,
 		.pTests = vcn_tests,
 	},
+	{
+		.pName = "UVD ENC Tests",
+		.pInitFunc = suite_uvd_enc_tests_init,
+		.pCleanupFunc = suite_uvd_enc_tests_clean,
+		.pTests = uvd_enc_tests,
+	},
+	{
+		.pName = "Deadlock Tests",
+		.pInitFunc = suite_deadlock_tests_init,
+		.pCleanupFunc = suite_deadlock_tests_clean,
+		.pTests = deadlock_tests,
+	},
 	CU_SUITE_INFO_NULL,
 };
 
